# Change log

## v1.1.4

Date: 2019-06-10

- Fixed bug: 無法 rput array of object.
- Fixed import error.

## v1.1.3

Date: 2019-06-03  

- Fixed import error.

## v1.1.2

Date: 2019-06-03  

- Fixed error: cannot import 'NuDB'.

## v1.1.1

Date: 2019-05-30  

- 可取得 DB 資訊 (getDBInfo)
- 修改 Error Hanlder
- 支援更新指定欄位的資料
- 支援使用 primary key 來 get/delete/update record

## v1.0.0 ~ v1.1.0

支援以下功能:

- Search
- Get record by rid
- Put record
- Put record from file
- Delete record by rid
- Update record
